@@ -11,10 +11,6 @@ module Rouge
 
       filenames '*.erb', '*.erubis', '*.rhtml', '*.eruby'
 
-      def self.analyze_text(text)
-        return 0.4 if text =~ /<%.*%>/
-      end
-
       def initialize(opts={})
         @ruby_lexer = Ruby.new(opts)
 
@@ -41,7 +37,7 @@ module Rouge
 
       state :comment do
         rule close, Comment, :pop!
-        rule /.+(?=#{close})|.+/m, Comment
+        rule /.+?(?=#{close})|.+/m, Comment
       end
 
       state :ruby do
