@@ -9,9 +9,9 @@ module Rouge
       filenames '*.htm', '*.html', '*.xhtml'
       mimetypes 'text/html', 'application/xhtml+xml'
 
-      def self.analyze_text(text)
-        return 1 if text.doctype?(/\bhtml\b/i)
-        return 1 if text =~ /<\s*html\b/
+      def self.detect?(text)
+        return true if text.doctype?(/\bhtml\b/i)
+        return true if text =~ /<\s*html\b/
       end
 
       start do
@@ -37,6 +37,7 @@ module Rouge
         rule /<\s*style\s*/m do
           token Name::Tag
           @css.reset!
+          @lang = @css
           push :style_content
           push :tag
         end
@@ -80,7 +81,7 @@ module Rouge
 
       state :tag do
         rule /\s+/m, Text
-        rule /[a-zA-Z0-9_:-]+\s*=/m, Name::Attribute, :attr
+        rule /[a-zA-Z0-9_:-]+\s*=\s*/m, Name::Attribute, :attr
         rule /[a-zA-Z0-9_:-]+/, Name::Attribute
         rule %r(/?\s*>)m, Name::Tag, :pop!
       end
@@ -124,13 +125,13 @@ module Rouge
 
       state :style_content do
         rule /[^<]+/ do
-          delegate @css
+          delegate @lang
         end
 
         rule %r(<\s*/\s*style\s*>)m, Name::Tag, :pop!
 
         rule /</ do
-          delegate @css
+          delegate @lang
         end
       end
     end
